@@ -8,8 +8,7 @@ from tqdm import tqdm
 import amical
 from amical.analysis import models
 from amical.dpfit import leastsqFit
-from amical.tools import mas2rad
-from amical.tools import roundSciDigit
+from amical.tools import mas2rad, roundSciDigit
 
 if sys.platform == "darwin":
     multiprocessing.set_start_method(
