@@ -12,6 +12,7 @@ Set of functions to calibrate NRM data using a calibrator star data.
 import numpy as np
 
 from amical.dpfit import leastsqFit
+from amical.externals.munch import munchify as dict2class
 from amical.tools import wtmn
 
 
@@ -191,7 +192,6 @@ def average_calib_files(list_nrm, sig_thres=2, display=False):
     `sig_thres` : {float}
         Threshold of the sigma clipping (default: 2-sigma around the median is used),\n
     """
-    from munch import munchify as dict2class
     from astropy.io import fits
 
     nfiles = len(list_nrm)
@@ -306,8 +306,6 @@ def calibrate(
         NRM data, inputs of this function).
     """
 
-    from munch import munchify as dict2class
-
     if type(res_c) is not list:
         res_c = [res_c]
 
