@@ -15,6 +15,8 @@ import warnings
 import numpy as np
 from termcolor import cprint
 
+from amical.externals.munch import munchify as dict2class
+
 
 def linear(x, param):
     """Linear model used in dpfit"""
@@ -368,7 +370,6 @@ def jd2lst(lng, jd):
 
 
 def compute_pa(hdr, n_ps, verbose=False, display=False, *, sci_hdr=None):
-
     list_fct_pa = {
         "SPHERE": (sphere_parang, {"hdr": hdr, "n_dit_ifs": n_ps}),
         "NIRISS": (niriss_parang, {"hdr": sci_hdr}),
@@ -521,9 +522,7 @@ def sphere_parang(hdr, n_dit_ifs=None):
     time_to_lst = (24.0 * 3600.0) / (86164.1)
 
     if "ESO INS4 COMB ROT" in hdr.keys() and hdr["ESO INS4 COMB ROT"] == "PUPIL":
-
         for i in range(n_frames):
-
             ha_deg = (
                 (lst_start + i * delta_dit * time_to_lst + time_to_lst * dit / 2.0)
                 * 15.0
@@ -598,7 +597,6 @@ def check_seeing_cond(list_nrm):  # pragma: no cover
 
     """
     from astropy.io import fits
-    from munch import munchify as dict2class
 
     l_seeing, l_vis2, l_cp, l_pa, l_mjd = [], [], [], [], []
 
@@ -735,7 +733,6 @@ def load_bs_hdf5(filename):
     """Load hdf5 file and format as class like object (same
     format as `amical.extract_bs()`
     """
-    from munch import munchify as dict2class
     import h5py
 
     dict_bs = {"matrix": {}, "infos": {"hdr": {}}, "mask": {}}
